@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package LWP::ConsoleLogger;
-$LWP::ConsoleLogger::VERSION = '0.000012';
+$LWP::ConsoleLogger::VERSION = '0.000013';
 use Data::Printer { end_separator => 1, hash_separator => ' => ' };
 use DateTime qw();
 use Email::MIME qw();
@@ -19,7 +19,7 @@ use MooseX::Types::Common::Numeric qw( PositiveInt );
 use MooseX::Types::Moose qw( Bool CodeRef );
 use Parse::MIME qw( parse_mime_type );
 use Term::Size::Any qw( chars );
-use Text::SimpleTable::AutoWidth qw();
+use Text::SimpleTable::AutoWidth 0.09 qw();
 use Try::Tiny;
 use URI::Query qw();
 use URI::QueryParam qw();
@@ -59,12 +59,30 @@ has dump_params => (
     default => 1,
 );
 
+has dump_status => (
+    is      => 'rw',
+    isa     => Bool,
+    default => 1,
+);
+
 has dump_text => (
     is      => 'rw',
     isa     => Bool,
     default => 1,
 );
 
+has dump_title => (
+    is      => 'rw',
+    isa     => Bool,
+    default => 1,
+);
+
+has dump_uri => (
+    is      => 'rw',
+    isa     => Bool,
+    default => 1,
+);
+
 has html_restrict => (
     is      => 'rw',
     isa     => 'HTML::Restrict',
@@ -76,6 +94,7 @@ has logger => (
     is      => 'rw',
     isa     => 'Log::Dispatch',
     lazy    => 1,
+    handles => { _debug => 'debug' },
     default => sub {
         return Log::Dispatch->new(
             outputs => [ [ 'Screen', min_level => 'debug', newline => 1, ], ],
@@ -108,9 +127,12 @@ sub request_callback {
     my $req  = shift;
     my $ua   = shift;
 
-    my $uri_without_query = $req->uri->clone;
-    $uri_without_query->query( undef );
-    $self->logger->debug( $req->method . q{ } . $uri_without_query . "\n" );
+    if ( $self->dump_uri ) {
+        my $uri_without_query = $req->uri->clone;
+        $uri_without_query->query( undef );
+
+        $self->_debug( $req->method . q{ } . $uri_without_query . "\n" );
+    }
 
     if ( $req->method eq 'GET' ) {
         $self->_log_params( $req, 'GET' );
@@ -129,9 +151,13 @@ sub response_callback {
     my $res  = shift;
     my $ua   = shift;
 
-    $self->logger->debug( $res->status_line . "\n" );
-    $self->logger->debug( 'Title: ' . $ua->title . "\n" )
-        if $ua->can( 'title' ) && $ua->title;
+    if ( $self->dump_status ) {
+        $self->_debug( '==> ' . $res->status_line . "\n" );
+    }
+    if ( $self->dump_title && $ua->can( 'title' ) && $ua->title ) {
+        $self->_debug( 'Title: ' . $ua->title . "\n" );
+    }
+
     $self->_log_headers( 'response', $res->headers );
     $self->_log_cookies( 'response', $ua->cookie_jar );
 
@@ -146,14 +172,14 @@ sub _log_headers {
     return if !$self->dump_headers;
 
     my $t = Text::SimpleTable::AutoWidth->new();
-    $t->captions( [ 'Header Name', 'Value' ] );
+    $t->captions( [ ucfirst $type . ' Header', 'Value' ] );
 
     foreach my $name ( sort $headers->header_field_names ) {
         next if $name eq 'Cookie' || $name eq 'Set-Cookie';
         $t->row( $name, $headers->header( $name ) );
     }
 
-    $self->_draw( $t, ucfirst $type . " Headers:\n" );
+    $self->_draw( $t );
 }
 
 sub _log_params {
@@ -295,14 +321,14 @@ sub _log_text {
     elsif ( lc $subtype eq 'xml' ) {
         try {
             my $pretty = XMLin( $content, KeepRoot => 1 );
-            $content = p $pretty;
-            $content =~ s{^\\ }{}; # don't prefix HashRef with slash
+            $content = p( $pretty );
+            $content =~ s{^\\ }{};    # don't prefix HashRef with slash
         }
         catch { $t->row( "Error parsing XML: $_" ) };
     }
     elsif ( lc $subtype eq 'json' ) {
         try {
-            $content = p decode_json( $content );
+            $content = p( decode_json( $content ) );
         }
         catch { $t->row( "Error parsing JSON: $_" ) };
     }
@@ -336,8 +362,8 @@ sub _draw {
     my $preamble = shift;
 
     return if !$t->rows;
-    $self->logger->debug( $preamble ) if $preamble;
-    $self->logger->debug( $t->draw );
+    $self->_debug( $preamble ) if $preamble;
+    $self->_debug( $t->draw );
 }
 
 1;
@@ -352,7 +378,7 @@ LWP::ConsoleLogger - LWP tracing and debugging
 
 =head1 VERSION
 
-version 0.000012
+version 0.000013
 
 =head1 SYNOPSIS
 
@@ -404,7 +430,7 @@ version 0.000012
 
     GET http://www.nytimes.com/2014/04/24/technology/fcc-new-net-neutrality-rules.html
 
-    Params:
+    GET params:
     .-----+-------.
     | Key | Value |
     +-----+-------+
@@ -412,9 +438,8 @@ version 0.000012
     | hp  |       |
     '-----+-------'
 
-    Request Headers:
     .-----------------+--------------------------------.
-    | Header Name     | Value                          |
+    | Request Header  | Value                          |
     +-----------------+--------------------------------+
     | Accept-Encoding | gzip                           |
     | Cookie2         | $Version="1"                   |
@@ -422,13 +447,12 @@ version 0.000012
     | User-Agent      | WWW-Mechanize/1.73             |
     '-----------------+--------------------------------'
 
-    200 OK
+    ==> 200 OK
 
     Title: The New York Times - Breaking News, World News & Multimedia
 
-    Response Headers:
     .--------------------------+-------------------------------.
-    | Header Name              | Value                         |
+    | Response Header          | Value                         |
     +--------------------------+-------------------------------+
     | Accept-Ranges            | bytes                         |
     | Age                      | 176                           |
@@ -493,8 +517,16 @@ here and discuss them in detail below.
 
 =item * C<< dump_params => 0|1 >>
 
+=item * C<< dump_status => 0|1 >>
+
 =item * C<< dump_text => 0|1 >>
 
+=item * C<< dump_title => 0|1 >>
+
+=item * C<< dump_text => 0|1 >>
+
+=item * C<< dump_uri => 0|1 >>
+
 =item * C<< content_pre_filter => sub { ... } >>
 
 =item * C<< text_pre_filter => sub { ... } >>
@@ -533,11 +565,26 @@ Defaults to true.
 
 Params are dumped in alphabetical order.
 
+=head2 dump_status( 0|1 )
+
+Boolean value. If true, dumps the HTTP response code for each page being
+visited.  Defaults to true.
+
 =head2 dump_text( 0|1 )
 
 Boolean value. If true, dumps the text of your page after both the
 content_pre_filter and text_pre_filters have been applied.  Defaults to true.
 
+=head2 dump_title( 0|1 )
+
+Boolean value. If true, dumps the titles of HTML pages if your UserAgent has
+a c<title> method and if it returns something useful. Defaults to true.
+
+=head2 dump_uri( 0|1 )
+
+Boolean value. If true, dumps the URI of each page being visited. Defaults to
+true.
+
 =head2 content_pre_filter( sub { ... } )
 
 Subroutine reference.  This allows you to manipulate content before it is
